Learn R Programming

NGLVieweR (version 1.4.0)

NGLVieweR_example: Run NGLVieweR example Shiny app

Description

Launch an example to demonstrate how to use NGLvieweR in Shiny.

Usage

NGLVieweR_example(example = "basic")

Value

Call to load Shiny example.

Arguments

example

Example type for which to see an example, possible values are: "basic", "API", "addSelection", "removeSelection", "snapshot", "updateAnimation", "updateColor", "updateFocus", "updateFullscreen", "updateRepresentation", "updateSelection", "updateStage", "updateVisibility", "updateZoomMove", "multiStructureSelection".

Examples

Run this code

if (interactive()) {

# Basic example
NGLVieweR_example("basic")

# Example with API calls
NGLVieweR_example("API")

# Function specific example
NGLVieweR_example("addSelection")
}

Run the code above in your browser using DataLab