NGLVieweR_example: Run NGLVieweR example Shiny app
Description
Launch an example to demonstrate how to use NGLvieweR in
Shiny.
Usage
NGLVieweR_example(example = "basic")
Value
Call to load Shiny example.
Arguments
example
Example type for which to see an example, possible values are:
"basic", "API", "addSelection", "removeSelection", "snapshot",
"updateAnimation", "updateColor", "updateFocus", "updateFullscreen",
"updateRepresentation", "updateSelection", "updateStage", "updateVisibility",
"updateZoomMove", "multiStructureSelection".
if (interactive()) {
# Basic exampleNGLVieweR_example("basic")
# Example with API callsNGLVieweR_example("API")
# Function specific exampleNGLVieweR_example("addSelection")
}